@@ -325,7 +325,6 @@ class Test_set_option(unittest.TestCase):
         self.assertEqual(my_var.value(), 122*1024*1024, "Failed test OPTION_LOCALSIZE")
         cleanup()
         
-        
 class Test_initialization(unittest.TestCase):
     def test_init_cleanup_loop(self):
         my_var=None
@@ -346,10 +345,45 @@ class Test_initialization(unittest.TestCase):
         cleanup()
         with self.assertRaises(pyclpEx):
             cleanup()
+   
+        
+     
+class Test_external_predicates(unittest.TestCase):
+    """
+    Test calling python function from eclipse.
+    """
+    def setUp(self):
+        init()
+        self.stdout=Stream('stdout')
+    def tearDown(self):
+        self.stdout.close()
+        cleanup()
+    def test_call_with_arguments_and_unify(self):
+        eclipse_name='p_func'
+        
+        def called_from_eclipse(arguments):
+            return unify(arguments[0],arguments[1])
+        
+        addPythonFunction(eclipse_name,called_from_eclipse)
+        my_var=Var()
+        Compound('call_python_function',Atom(eclipse_name),[1,my_var]).post_goal()
+        self.assertEqual(resume(),(SUCCEED,None),"Failed resume ")
+        self.assertEqual(my_var.value(),1,"Failed unification")
+    def test_call_with_exception(self):
+        """Test python exception generated by eclispe when calling an external predicate
+        implemented in python 
+        """
+        eclipse_name='p_func'
+        def called_from_eclipse(arguments):
+            a=a +1 
+            return SUCCEED
+        addPythonFunction(eclipse_name,called_from_eclipse)
+        my_var=Var()
+        Compound('call_python_function',Atom(eclipse_name),[1,my_var]).post_goal()
+        with self.assertRaises(UnboundLocalError) as exp:
+            resume()
+        
         
-            
-            
-            
 
 if __name__ == '__main__':
    unittest.main()
